pub enum DecoderError {
InvalidInput,
InvalidIndex,
InvalidPrefix,
IntegerOverflow,
IntegerUnderflow,
InvalidMaxDynamicSize,
}Expand description
Contains error options that can be encountered while performing the decoding of an HPACK header set.
Variants
InvalidInput
Indicates that the decoder received an invalid (Huffman) buffer. This should never happen if the input is encoded according to the HPACK spec.
InvalidIndex
Indicates that an invalid index was provided. According to the HPACK
specification, the index 0 must be treated as an invalid index number.
The first valid number is 1.
InvalidPrefix
Indicates that an invalid prefix was provided (must be [1, 8]).
IntegerOverflow
Indicates that the value of the integer being decoded exceeds a certain threshold (5 bytes are chosen by this implementation).
IntegerUnderflow
Indicates that the buffer from which an integer was supposed to be decode does not contain enough octets to complete the decoding.
InvalidMaxDynamicSize
Indicates that the decoder received a size that do not follow external protocol rules.